@@ -175,12 +175,18 @@ public:
     */
     MatrixSparseSymmetricBlock  mC;
     
-    /// base for force
+    /// base for force derivative
     real*   base()             { return vBAS; }
 
     /// base for force
     real&   base(index_t i) { return vBAS[i]; }
     
+    /// base for points
+    real*   points()             { return vPTS; }
+    
+    /// base for force
+    real*   force()             { return vFOR; }
+    
     /// position of point stored at vPTS[i]
     Vector  position1(const index_t inx) const
     {
