@@ -14,10 +14,12 @@
 #include "unistd.h"
 #include "python_frame.h"
 #include "simul_modules.h"
+#include "interface_modules.h"
 #include "fiber_modules.h"
 #include "solid_modules.h"
 #include "space_modules.h"
 #include "point_modules.h"
+#include "thread_modules.h"
 #include "single_modules.h"
 #include "meca_modules.h"
 #include "couple_modules.h"
@@ -30,4 +32,5 @@ namespace py = pybind11;
 
 void bar(void);
 class SimThread;
+
 #endif
